/*
 * Copyright (c) 2001 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.html;

/**
 * Embedded image. See the IMG element definition in HTML 4.0.
 * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-2-HTML-20011210'>Document Object Model (DOM) Level 2 HTML Specification</a>.
 */
public interface HTMLImageElement extends HTMLElement {
    /**
     * The name of the element (for backwards compatibility). 
     */
    public String getName();
    /**
     * The name of the element (for backwards compatibility). 
     */
    public void setName(String name);

    /**
     * Aligns this object (vertically or horizontally) with respect to its 
     * surrounding text. See the align attribute definition in HTML 4.0. 
     * This attribute is deprecated in HTML 4.0.
     */
    public String getAlign();
    /**
     * Aligns this object (vertically or horizontally) with respect to its 
     * surrounding text. See the align attribute definition in HTML 4.0. 
     * This attribute is deprecated in HTML 4.0.
     */
    public void setAlign(String align);

    /**
     * Alternate text for user agents not rendering the normal content of this 
     * element. See the alt attribute definition in HTML 4.0.
     */
    public String getAlt();
    /**
     * Alternate text for user agents not rendering the normal content of this 
     * element. See the alt attribute definition in HTML 4.0.
     */
    public void setAlt(String alt);

    /**
     * Width of border around image in pixels. See the  border attribute 
     * definition in HTML 4.0. This attribute is deprecated in HTML 4.0. 
     * Note that the type of this attribute was <code>DOMString</code> in 
     * DOM Level 1 HTML .
     */
    public int getBorder();
    /**
     * Width of border around image in pixels. See the  border attribute 
     * definition in HTML 4.0. This attribute is deprecated in HTML 4.0. 
     * Note that the type of this attribute was <code>DOMString</code> in 
     * DOM Level 1 HTML .
     */
    public void setBorder(int border);

    /**
     * Height of the image in pixels. See the height attribute definition in 
     * HTML 4.0. Note that the type of this attribute was 
     * <code>DOMString</code> in DOM Level 1 HTML .
     */
    public int getHeight();
    /**
     * Height of the image in pixels. See the height attribute definition in 
     * HTML 4.0. Note that the type of this attribute was 
     * <code>DOMString</code> in DOM Level 1 HTML .
     */
    public void setHeight(int height);

    /**
     * Horizontal space to the left and right of this image in pixels. See the 
     * hspace attribute definition in HTML 4.0. This attribute is deprecated 
     * in HTML 4.0. Note that the type of this attribute was 
     * <code>DOMString</code> in DOM Level 1 HTML .
     */
    public int getHspace();
    /**
     * Horizontal space to the left and right of this image in pixels. See the 
     * hspace attribute definition in HTML 4.0. This attribute is deprecated 
     * in HTML 4.0. Note that the type of this attribute was 
     * <code>DOMString</code> in DOM Level 1 HTML .
     */
    public void setHspace(int hspace);

    /**
     * Use server-side image map. See the ismap attribute definition in HTML 
     * 4.0.
     */
    public boolean getIsMap();
    /**
     * Use server-side image map. See the ismap attribute definition in HTML 
     * 4.0.
     */
    public void setIsMap(boolean isMap);

    /**
     * URI  designating a long description of this image or frame. See the 
     * longdesc attribute definition in HTML 4.0.
     */
    public String getLongDesc();
    /**
     * URI  designating a long description of this image or frame. See the 
     * longdesc attribute definition in HTML 4.0.
     */
    public void setLongDesc(String longDesc);

    /**
     * URI  designating the source of this image. See the src attribute 
     * definition in HTML 4.0.
     */
    public String getSrc();
    /**
     * URI  designating the source of this image. See the src attribute 
     * definition in HTML 4.0.
     */
    public void setSrc(String src);

    /**
     * Use client-side image map. See the usemap attribute definition in HTML 
     * 4.0.
     */
    public String getUseMap();
    /**
     * Use client-side image map. See the usemap attribute definition in HTML 
     * 4.0.
     */
    public void setUseMap(String useMap);

    /**
     * Vertical space above and below this image in pixels. See the vspace 
     * attribute definition in HTML 4.0. This attribute is deprecated in 
     * HTML 4.0. Note that the type of this attribute was "DOMString" in DOM 
     * Level 1 HTML .
     */
    public int getVspace();
    /**
     * Vertical space above and below this image in pixels. See the vspace 
     * attribute definition in HTML 4.0. This attribute is deprecated in 
     * HTML 4.0. Note that the type of this attribute was "DOMString" in DOM 
     * Level 1 HTML .
     */
    public void setVspace(int vspace);

    /**
     * The width of the image in pixels. See the width attribute definition in 
     * HTML 4.0. Note that the type of this attribute was 
     * <code>DOMString</code> in DOM Level 1 HTML .
     */
    public int getWidth();
    /**
     * The width of the image in pixels. See the width attribute definition in 
     * HTML 4.0. Note that the type of this attribute was 
     * <code>DOMString</code> in DOM Level 1 HTML .
     */
    public void setWidth(int width);

}
